summaryrefslogtreecommitdiff
path: root/Magefile.go
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2025-09-07 14:29:35 +0300
committerPaul Buetow <paul@buetow.org>2025-09-07 14:29:35 +0300
commit23482b5d8da5c67da1fc501ddbafdd123be3972c (patch)
tree452dc7c418055ebb79a88a303e50d2dbc1877f09 /Magefile.go
parent76f388f9759cdc15cb1eba985cd87cde1906208b (diff)
feat: rename hexai-action -> hexai-tmux-action; remove --tmux/--no-tmux; tmux-only flow; update docs and Magefile
Diffstat (limited to 'Magefile.go')
-rw-r--r--Magefile.go26
1 files changed, 13 insertions, 13 deletions
diff --git a/Magefile.go b/Magefile.go
index 16ff7c0..5c5be0b 100644
--- a/Magefile.go
+++ b/Magefile.go
@@ -17,16 +17,16 @@ import (
)
var (
- Default = Build // Default target: build all binaries.
+ Default = Build // Default target: build all binaries.
coverageThreshold float64 = 85
coveragePrinted = make(chan struct{}, 1)
)
-// Build builds the Hexai LSP and CLI binaries.
+// Build builds binaries.
func Build() error {
- mg.Deps(BuildHexaiLSP, BuildHexaiCLI, BuildHexaiAction)
- printCoverage()
- return nil
+ mg.Deps(BuildHexaiLSP, BuildHexaiCLI, BuildHexaiTmuxAction)
+ printCoverage()
+ return nil
}
// BuildHexaiLSP builds the LSP server binary.
@@ -41,10 +41,10 @@ func BuildHexaiCLI() error {
return sh.RunV("go", "build", "-o", "hexai", "cmd/hexai/main.go")
}
-// BuildHexaiAction builds the hexai-action TUI binary.
-func BuildHexaiAction() error {
+// BuildHexaiTmuxAction builds the hexai-tmux-action TUI binary.
+func BuildHexaiTmuxAction() error {
printCoverage()
- return sh.RunV("go", "build", "-o", "hexai-action", "cmd/hexai-action/main.go")
+ return sh.RunV("go", "build", "-o", "hexai-tmux-action", "cmd/hexai-tmux-action/main.go")
}
// Dev runs tests, vet, lint, then builds with race for both binaries.
@@ -57,7 +57,7 @@ func Dev() error {
if err := sh.RunV("go", "build", "-race", "-o", "hexai", "cmd/hexai/main.go"); err != nil {
return err
}
- return sh.RunV("go", "build", "-race", "-o", "hexai-action", "cmd/hexai-action/main.go")
+ return sh.RunV("go", "build", "-race", "-o", "hexai-tmux-action", "cmd/hexai-tmux-action/main.go")
}
// Run launches the LSP server via go run (useful during development).
@@ -97,14 +97,14 @@ func Install() error {
if err := sh.RunV("cp", "-v", "./hexai", bin+"/"); err != nil {
return err
}
- return sh.RunV("cp", "-v", "./hexai-action", bin+"/")
+ return sh.RunV("cp", "-v", "./hexai-tmux-action", bin+"/")
}
-// RunAction runs the hexai-action TUI via go run (reads stdin).
-func RunAction() error {
+// RunTmuxAction runs the hexai-tmux-action TUI via go run (reads stdin).
+func RunTmuxAction() error {
printCoverage()
mg.Deps(Dev)
- return sh.RunV("go", "run", "cmd/hexai-action/main.go")
+ return sh.RunV("go", "run", "cmd/hexai-tmux-action/main.go")
}
// printCoverage prints a warning if an existing coverage profile shows total < coverateThreshold.